##  How to Add the Workspace Best Practice Report to Your Workspace
To add this report to your workspace, go to the SAP LeanIX store by going to More > Store in the top menu. In the store, find and add the Workspace Best Practice Report.
Optionally, you can access the report at the following link:[Workspace Best Practice Report![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.leanix.net%2Fen%2Fdetails%2Freport%2Ffb98544c-d8c8-4892-877b-455675c97617%2F918032b5-1cd9-4e9a-b5f6-37daf0d2beec "https://store.leanix.net/en/details/report/fb98544c-d8c8-4892-877b-455675c97617/918032b5-1cd9-4e9a-b5f6-37daf0d2beec").
![The SAP LeanIX dashboard with the More menu open and Store option highlighted.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3f8998b9688d41a5bc8bdfde7859cf64_LowRes.png)
Accessing the Store in LeanIX
Click on Add to Workspace or Add to Multiple Workspace depending on your needs. Agree to terms and condition and finish adding it to your workspace. Once the report has been added, it has to be activated and made available in the reports.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745e7e57a44101499d7eec53b0ee36a_LowRes.png)
To activate the report go to administration settings, and under advanced settings click on Reports. The newly added Workspace Best Practice Report will be visible in the list of added reports. You can hover over the report and click on Show report icon to to make it visible in the reports section of your workspace.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f1d767a441014be6bbaf153d70742_LowRes.png)
Now at the end, if you have made the mentioned settings you should be able to find the Workspace Best Practice Report in your reports in Other section. Reload the page once in your workspace if needed.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275243b37a44101494d7aebe6baa14b3_LowRes.png)
YesNo
Send
